import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { DropdownPlacement_$type } from "./DropdownPlacement";
import { DropdownPositionStrategy_$type } from "./DropdownPositionStrategy";
import { DropdownScrollStrategy_$type } from "./DropdownScrollStrategy";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { IgrDropdownItemComponentEventArgs } from "./igr-dropdown-item-component-event-args";
import { IgrDropdownItem } from "./igr-dropdown-item";
import { Dropdown } from "./Dropdown";
import { TypeRegistrar } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgcDropdownComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, ensureEnum, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * Represents a DropDown component.
*/
export class IgrDropdown extends React.Component {
    createImplementation() {
        return new Dropdown();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    constructor(props) {
        super(props);
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._change = null;
        this._change_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcDropdownComponent);
        this._implementation = this.createImplementation();
        this._portalManager = new PortalManager("templates", () => this.setState({}));
        this._renderer = new ReactRenderer(this._implementation.nativeElement, document, false, null, this._portalManager);
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let div = React.createElement("igc-dropdown", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Whether the dropdown should be kept open on selection.
    */
    get keepOpenOnSelect() {
        return this.i.l;
    }
    set keepOpenOnSelect(v) {
        this.i.l = ensureBool(v);
    }
    /**
     * Sets the open state of the component.
    */
    get open() {
        return this.i.m;
    }
    set open(v) {
        this.i.m = ensureBool(v);
    }
    /**
     * The preferred placement of the component around the target element.
     * @type {"top" | "top-start" | "top-end" | "bottom" | "bottom-start" | "bottom-end" | "right" | "right-start" | "right-end" | "left" | "left-start" | "left-end"}
    */
    get placement() {
        return this.i.d;
    }
    set placement(v) {
        this.i.d = ensureEnum(DropdownPlacement_$type, v);
    }
    /**
     * Sets the component's positioning strategy.
    */
    get positionStrategy() {
        return this.i.e;
    }
    set positionStrategy(v) {
        this.i.e = ensureEnum(DropdownPositionStrategy_$type, v);
    }
    /**
     * Determines the behavior of the component during scrolling the container.
    */
    get scrollStrategy() {
        return this.i.f;
    }
    set scrollStrategy(v) {
        this.i.f = ensureEnum(DropdownScrollStrategy_$type, v);
    }
    /**
     * Whether the component should be flipped to the opposite side of the target once it's about to overflow the visible area.
     * When true, once enough space is detected on its preferred side, it will flip back.
    */
    get flip() {
        return this.i.j;
    }
    set flip(v) {
        this.i.j = ensureBool(v);
    }
    /**
     * The distance from the target element.
    */
    get distance() {
        return this.i.o;
    }
    set distance(v) {
        this.i.o = +v;
    }
    /**
     * Whether the component should be kept open on clicking outside of it.
    */
    get keepOpenOnOutsideClick() {
        return this.i.k;
    }
    set keepOpenOnOutsideClick(v) {
        this.i.k = ensureBool(v);
    }
    /**
     * Whether the dropdown's width should be the same as the target's one.
    */
    get sameWidth() {
        return this.i.n;
    }
    set sameWidth(v) {
        this.i.n = ensureBool(v);
    }
    get size() {
        return this.i.g;
    }
    set size(v) {
        this.i.g = ensureEnum(SizableComponentSize_$type, v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Dropdown");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    /**
     * Shows the dropdown.
    
    */
    show() {
        this.i.v();
    }
    /**
     * Toggles the open state of the dropdown.
    
    */
    toggle() {
        this.i.x();
    }
    /**
     * Shows the dropdown.
    
    */
    showTarget(target_) {
        this.i.showTarget(target_);
    }
    /**
     * Toggles the open state of the dropdown.
    
    */
    toggleTarget(target_) {
        this.i.toggleTarget(target_);
    }
    /**
     * Navigates to the item at the specified index. If it exists, returns the found item, otherwise - null.
    
    */
    navigateTo(index) {
        let iv = this.i.a(index);
        let ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                let e = IgrDropdownItem._createFromInternal(iv);
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    }
    /**
     * Selects the item with the specified value. If it exists, returns the found item, otherwise - null.
    
    */
    select(value) {
        let iv = this.i.b(value);
        let ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                let e = IgrDropdownItem._createFromInternal(iv);
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    /**
     * Hides the dropdown.
    
    */
    hide() {
        this.i.t();
    }
    /**
     * Clears the current selection of the dropdown.
    
    */
    clearSelection() {
        this.i.s();
    }
    get change() {
        return this._change;
    }
    set change(ev) {
        if (this._change_wrapped !== null) {
            this.i.change = delegateRemove(this.i.change, this._change_wrapped);
            this._change_wrapped = null;
            this._change = null;
        }
        this._change = ev;
        this._change_wrapped = (o, e) => {
            let outerArgs = new IgrDropdownItemComponentEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeChange) {
                this.beforeChange(this, outerArgs);
            }
            if (this._change) {
                this._change(this, outerArgs);
            }
        };
        this.i.change = delegateCombine(this.i.change, this._change_wrapped);
        if (this.i.changeChanged) {
            this.i.changeChanged();
        }
        ;
    }
}
