import * as React from 'react';
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { IgrMaskInputBase } from "./igr-mask-input-base";
import { MaskInput } from "./MaskInput";
import { IgcMaskInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum } from "igniteui-react-core";
/**
 * A masked input is an input field where a developer can control user input and format the visible value,
 * based on configurable rules
*/
export class IgrMaskInput extends IgrMaskInputBase {
    createImplementation() {
        return new MaskInput();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcMaskInputComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-mask-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Dictates the behavior when retrieving the value of the control:
     * - `raw` will return the clean user input.
     * - `withFormatting` will return the value with all literals and prompts.
    */
    get valueMode() {
        return this.i.ae;
    }
    set valueMode(v) {
        this.i.ae = ensureEnum(MaskInputValueMode_$type, v);
    }
    get value() {
        return this.i.ag;
    }
    set value(v) {
        this.i.ag = v;
    }
    /**
     * The mask pattern to apply on the input.
    */
    get mask() {
        return this.i.af;
    }
    set mask(v) {
        this.i.af = v;
    }
    /**
     * Checks for validity of the control and shows the browser message if it's invalid.
    
    */
    reportValidity() {
        this.i.ai();
    }
    /**
     * Check for validity of the control
    
    */
    checkValidity() {
        this.i.ah();
    }
}
