import * as React from 'react';
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { Snackbar } from "./Snackbar";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { ContentChildrenManager } from "igniteui-react-core";
/**
 * A snackbar component is used to provide feedback about an operation
 * by showing a brief message at the bottom of the screen.
*/
export declare class IgrSnackbar<P extends IIgrSnackbarProps = IIgrSnackbarProps> extends React.Component<P, {}> {
    protected createImplementation(): Snackbar;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): Snackbar; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrSnackbar;
    protected _renderer: ReactRenderer;
    protected _portalManager: PortalManager;
    private onImplementationCreated;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        className: P["className"];
        style: P["style"];
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * Determines whether the snackbar is opened.
    */
    get open(): boolean;
    set open(v: boolean);
    /**
     * Determines the duration in ms in which the snackbar will be visible.
    */
    get displayTime(): number;
    set displayTime(v: number);
    /**
     * Determines whether the snackbar should close after the displayTime is over.
    */
    get keepOpen(): boolean;
    set keepOpen(v: boolean);
    /**
     * The snackbar action button.
    */
    get actionText(): string;
    set actionText(v: string);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    setNativeElement(element: any): void;
    /**
     * Opens the snackbar.
    
    */
    show(): void;
    /**
     * Closes the snackbar.
    
    */
    hide(): void;
    /**
     * Toggles the open state of the component.
    
    */
    toggle(): void;
    private _action;
    private _action_wrapped;
    get action(): (s: IgrSnackbar, e: IgrVoidEventArgs) => void;
    set action(ev: (s: IgrSnackbar, e: IgrVoidEventArgs) => void);
}
export interface IIgrSnackbarProps {
    children?: React.ReactNode;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    /**
     * Determines whether the snackbar is opened.
    */
    open?: boolean | string;
    /**
     * Determines the duration in ms in which the snackbar will be visible.
    */
    displayTime?: number | string;
    /**
     * Determines whether the snackbar should close after the displayTime is over.
    */
    keepOpen?: boolean | string;
    /**
     * The snackbar action button.
    */
    actionText?: string;
    action?: (s: IgrSnackbar, e: IgrVoidEventArgs) => void;
}
